@@ -44,7 +44,8 @@ def run():
     learn.add_argument("--fit", dest="fit", type=float, default=0., help="tolerance over fitness (Default to 0)", metavar="F")
     learn.add_argument("--size", dest="size", type=int, default=0, help="tolerance over size (Default to 0)", metavar="S")
     learn.add_argument("--factor", dest="factor", type=int, default=100, choices=[1, 10, 100, 1000], help="discretization over [0,D] (Default to 100)", metavar="D")                        
-    learn.add_argument("--discretization", dest="discretization", default='round', choices=['round', 'floor', 'ceil'], help="discretization function: round, floor, ceil (Default to round)", metavar="T")                        
+    learn.add_argument("--discretization", dest="discretization", default='round', choices=['round', 'floor', 'ceil'], help="discretization function: round, floor, ceil (Default to round)", metavar="T")
+    learn.add_argument("--length", dest="length", type=int, default=0, help="max length for conjunctions (hyperedges) (Default to 0; unbounded)", metavar="L")
     learn.set_defaults(handler=handlers.learn)
     
     design = subparsers.add_parser("design", parents=[clingo_parser])
@@ -52,7 +53,9 @@ def run():
     design.add_argument("midas", help="experimental dataset in MIDAS file")                    
     design.add_argument("--stimuli", dest="stimuli", type=int, default=-1,help="maximum number of stimuli per experiment", metavar="S")
     design.add_argument("--inhibitors", dest="inhibitors", type=int, default=-1, help="maximum number of inhibitors per experiment", metavar="I")
-    design.add_argument("--experiments", dest="experiments", type=int, default=20, help="maximum number of experiments (Default to 20)", metavar="E")
+    design.add_argument("--nexp", dest="experiments", type=int, default=10, help="maximum number of experiments (Default to 10)", metavar="E")
+    design.add_argument("--list", dest="list", help="list of possible experiments", metavar="L")
+    design.add_argument("--relax", dest="relax", action='store_true', help="relax constraint about pairwise discrimination (Default to False)")
     design.set_defaults(handler=handlers.design)
     
     control = subparsers.add_parser("control")
@@ -69,6 +72,7 @@ def run():
     analyze.add_argument("--networks", dest="networks", help="logical networks in CSV format", metavar="N")
     analyze.add_argument("--midas", dest="midas", nargs=2, metavar=("M","T"), help="experimental dataset in MIDAS file and time-point to be used")
     analyze.add_argument("--strategies", help="intervention stratgies in CSV format", metavar="S")
+    analyze.add_argument("--networks-stats", dest="netstats", action='store_true', help="compute mutually inclusive/exclusive modules and MSE for each logical network (Default to False)")
     analyze.set_defaults(handler=handlers.analyze)
     
     visualize = subparsers.add_parser("visualize")
@@ -185,7 +189,8 @@ def run():
         args = parser.parse_args(['--out', out, 'analyze', '--clingo', clingo,
                                   '--networks', os.path.join(out, 'networks.csv'), 
                                   '--midas', os.path.join(out, 'dataset.csv'), 
-                                  params[0], '--strategies', os.path.join(out, 'strategies.csv')])
+                                  params[0], '--strategies', os.path.join(out, 'strategies.csv'),
+                                  '--networks-stats'])
                                   
         cmdline = "$ caspo --out {out} analyze --networks {networks} --midas {midas} {time} --strategies {strategies}"
         if clingo != 'clingo':
